# SQLAgent

SQLAgent is a toolkit that allows creating agents that interact with a SQL database.

It uses a [forked version](https://github.com/rvijayc/AgentRun) of the [AgentRun](https://github.com/tjmlabs/AgentRun) repository that allows safe execution of Python code inside a Docker container.

> Todo: More Documentation to follow.
